@@ -197,9 +197,12 @@ add_compress_arg (FrCommand *comm)
 	else if (is_mime_type (comm->mime_type, "application/x-bzip-compressed-tar"))
 		fr_process_add_arg (comm->process, "--use-compress-program=bzip2");
 
-	else if (is_mime_type (comm->mime_type, "application/x-tarz"))
-		fr_process_add_arg (comm->process, "-Z");
-
+	else if (is_mime_type (comm->mime_type, "application/x-tarz")) {
+		if (is_program_in_path ("gzip"))
+			fr_process_add_arg (comm->process, "-z");
+		else
+			fr_process_add_arg (comm->process, "-Z");
+	}
 	else if (is_mime_type (comm->mime_type, "application/x-lzma-compressed-tar"))
 		fr_process_add_arg (comm->process, "--use-compress-program=lzma");
 
@@ -209,6 +212,7 @@ add_compress_arg (FrCommand *comm)
 	else if (is_mime_type (comm->mime_type, "application/x-7z-compressed-tar")) {
 		FrCommandTar *comm_tar = (FrCommandTar*) comm;
 		char         *option;
+		
 		option = g_strdup_printf ("--use-compress-program=%s", comm_tar->compress_command);
 		fr_process_add_arg (comm->process, option);
 		g_free (option);
@@ -237,11 +241,9 @@ begin_tar_command (FrCommand *comm)
 
 
 static void
-fr_command_tar_list (FrCommand  *comm)
+fr_command_tar_list (FrCommand *comm)
 {
-	fr_process_set_out_line_func (FR_COMMAND (comm)->process,
-				      process_line,
-				      comm);
+	fr_process_set_out_line_func (comm->process, process_line, comm);
 
 	begin_tar_command (comm);
 	fr_process_add_arg (comm->process, "--force-local");
@@ -254,6 +256,13 @@ fr_command_tar_list (FrCommand  *comm)
 }
 
 
+static gboolean
+can_create_a_compressed_archive (FrCommand *comm)
+{
+	return comm->creating_archive && ! is_mime_type (comm->mime_type, "application/x-7z-compressed-tar");
+}
+
+
 static void
 process_line__generic (char     *line,
 		       gpointer  data,
@@ -315,8 +324,18 @@ fr_command_tar_add (FrCommand     *comm,
 		fr_process_add_arg (comm->process, base_dir);
 	}
 
-	fr_process_add_arg (comm->process, "-rf");
-	fr_process_add_arg (comm->process, c_tar->uncomp_filename);
+	if (can_create_a_compressed_archive (comm)) {
+		fr_process_add_arg (comm->process, "-cf");
+		fr_process_add_arg (comm->process, comm->filename);
+		add_compress_arg (comm);
+	}
+	else {
+		if (comm->creating_archive)
+			fr_process_add_arg (comm->process, "-cf");
+		else
+			fr_process_add_arg (comm->process, "-rf");
+		fr_process_add_arg (comm->process, c_tar->uncomp_filename);
+	}
 
 	if (from_file != NULL) {
 		fr_process_add_arg (comm->process, "-T");
@@ -454,11 +473,14 @@ begin_func__recompress (gpointer data)
 
 
 static void
-fr_command_tar_recompress (FrCommand     *comm)
+fr_command_tar_recompress (FrCommand *comm)
 {
 	FrCommandTar *c_tar = FR_COMMAND_TAR (comm);
 	char         *new_name = NULL;
 
+	if (can_create_a_compressed_archive (comm))
+		return;
+
 	if (is_mime_type (comm->mime_type, "application/x-compressed-tar")) {
 		fr_process_begin_command (comm->process, "gzip");
 		fr_process_set_sticky (comm->process, TRUE);
@@ -714,6 +736,9 @@ fr_command_tar_uncompress (FrCommand *comm)
 	char         *tmp_name;
 	gboolean      archive_exists;
 
+	if (can_create_a_compressed_archive (comm))
+		return;
+
 	if (c_tar->uncomp_filename != NULL) {
 		g_free (c_tar->uncomp_filename);
 		c_tar->uncomp_filename = NULL;
@@ -757,7 +782,10 @@ fr_command_tar_uncompress (FrCommand *comm)
 			fr_process_end_command (comm->process);
 		}
 		else if (is_mime_type (comm->mime_type, "application/x-tarz")) {
-			fr_process_begin_command (comm->process, "uncompress");
+			if (is_program_in_path ("gzip"))
+				fr_process_begin_command (comm->process, "gzip");
+			else
+				fr_process_begin_command (comm->process, "uncompress");
 			fr_process_set_begin_func (comm->process, begin_func__uncompress, comm);
 			fr_process_add_arg (comm->process, "-f");
 			fr_process_add_arg (comm->process, tmp_name);
@@ -815,14 +843,14 @@ fr_command_tar_handle_error (FrCommand   *comm,
 }
 
 
-const char *tar_mime_types[] = { "application/x-tar",
-			   "application/x-compressed-tar",
-			   "application/x-bzip-compressed-tar",
-			   "application/x-tarz",
-			   "application/x-lzma-compressed-tar",
-			   "application/x-lzop-compressed-tar",
-			   "application/x-7z-compressed-tar",
-			   NULL };
+const char *tar_mime_types[] = { "application/x-compressed-tar",
+				 "application/x-bzip-compressed-tar",
+				 "application/x-tar",
+				 "application/x-7z-compressed-tar",
+			         "application/x-lzma-compressed-tar",
+			         "application/x-lzop-compressed-tar",		         
+			         "application/x-tarz",
+			         NULL };
 
 
 const char **
@@ -855,11 +883,11 @@ fr_command_tar_get_capabilities (FrCommand  *comm,
 		if (is_program_in_path ("bzip2"))
 			capabilities |= FR_COMMAND_CAN_READ_WRITE;
 	}
-	else if (is_mime_type (mime_type, "application/x-tarz")) {
-		if (is_program_in_path ("compress"))
-			capabilities |= FR_COMMAND_CAN_WRITE;
-		if (is_program_in_path ("uncompress"))
-			capabilities |= FR_COMMAND_CAN_READ;
+	else if (is_mime_type (mime_type, "application/x-tarz")) {		
+		if (is_program_in_path ("compress") && is_program_in_path ("uncompress"))
+			capabilities |= FR_COMMAND_CAN_READ_WRITE;
+		else if (is_program_in_path ("gzip"))
+			capabilities |= FR_COMMAND_CAN_READ; 
 	}
 	else if (is_mime_type (mime_type, "application/x-lzma-compressed-tar")) {
 		if (is_program_in_path ("lzma"))
@@ -875,7 +903,7 @@ fr_command_tar_get_capabilities (FrCommand  *comm,
 
 		for (i = 0; i < G_N_ELEMENTS (try_command); i++) {
 			if (is_program_in_path (try_command[i])) {
-				capabilities |= FR_COMMAND_CAN_READ_WRITE;
+				capabilities |= FR_COMMAND_CAN_WRITE;
 				break;
 			}
 		}
