@@ -115,7 +115,9 @@ const char *fr_window_get_paste_archive_uri     (FrWindow      *window);
 gboolean    fr_window_archive_is_present        (FrWindow      *window);
 void        fr_window_archive_save_as           (FrWindow      *window,
 						 const char    *filename,
-						 const char    *password);
+						 const char    *password,
+						 gboolean       encrypt_header,
+						 guint          volume_size);
 void        fr_window_archive_reload            (FrWindow      *window);
 void        fr_window_archive_rename            (FrWindow      *window,
 						 const char    *filename);
@@ -129,28 +131,22 @@ void        fr_window_archive_add_with_wildcard (FrWindow      *window,
 						 const char    *base_dir,
 						 const char    *dest_dir,
 						 gboolean       update,
-						 gboolean       recursive,
 						 gboolean       follow_links);
 void        fr_window_archive_add_directory     (FrWindow      *window,
 						 const char    *directory,
 						 const char    *base_dir,
 						 const char    *dest_dir,
-						 gboolean       update,
-						 const char    *password,
-						 FrCompression  compression);
+						 gboolean       update);
 void        fr_window_archive_add_items         (FrWindow      *window,
 						 GList         *dir_list,
 						 const char    *base_dir,
 						 const char    *dest_dir,
-						 gboolean       update,
-						 const char    *password,
-						 FrCompression  compression);
+						 gboolean       update);
 void        fr_window_archive_add_dropped_items (FrWindow      *window,
 						 GList         *item_list,
 						 gboolean       update);
 void        fr_window_archive_remove            (FrWindow      *window,
-						 GList         *file_list,
-						 FrCompression  compression);
+						 GList         *file_list);
 void        fr_window_archive_extract           (FrWindow      *window,
 						 GList         *file_list,
 						 const char    *extract_to_dir,
@@ -158,21 +154,29 @@ void        fr_window_archive_extract           (FrWindow      *window,
 						 gboolean       skip_older,
 						 gboolean       overwrite,
 						 gboolean       junk_paths,
-						 const char    *password);
+						 gboolean       ask_to_open_destination);
 void        fr_window_archive_extract_here      (FrWindow      *window,
 						 gboolean       skip_older,
 						 gboolean       overwrite,
-						 gboolean       junk_paths,
-						 const char    *password);
-void        fr_window_archive_test	        (FrWindow      *window);					 
+						 gboolean       junk_paths);
+void        fr_window_archive_test	        (FrWindow      *window);
+
+/**/
+
 void        fr_window_set_password              (FrWindow      *window,
 						 const char    *password);
 void        fr_window_set_password_for_paste    (FrWindow      *window,
-					         const char    *password);						 
+					         const char    *password);
 const char *fr_window_get_password              (FrWindow      *window);
+void        fr_window_set_encrypt_header        (FrWindow      *window,
+						 gboolean       encrypt_header);
+gboolean    fr_window_get_encrypt_header        (FrWindow      *window);
+void        fr_window_set_compression 	        (FrWindow      *window,
+						 FrCompression  compression);
 FrCompression fr_window_get_compression 	(FrWindow      *window);
-void        fr_window_view_folder_after_extract (FrWindow      *window,
-					 	 gboolean       view);
+void        fr_window_set_volume_size 	        (FrWindow      *window,
+						 guint          volume_size);
+guint       fr_window_get_volume_size 	        (FrWindow      *window);
 
 /**/
 
@@ -205,10 +209,10 @@ GList *    fr_window_get_folder_tree_selection    (FrWindow    *window,
 				     		   gboolean    *has_dirs);
 GList *    fr_window_get_selection                (FrWindow    *window,
 		  	 			   gboolean     from_sidebar,
-		  	 			   char       **return_base_dir);				     		   
+		  	 			   char       **return_base_dir);
 GtkTreeModel *
 	   fr_window_get_list_store               (FrWindow    *window);
-void       fr_window_find                         (FrWindow    *window);	   
+void       fr_window_find                         (FrWindow    *window);
 void       fr_window_select_all                   (FrWindow    *window);
 void       fr_window_unselect_all                 (FrWindow    *window);
 void       fr_window_set_sort_type                (FrWindow    *window,
@@ -246,7 +250,7 @@ void        fr_window_open_files_with_application (FrWindow   *window,
 						   GList      *file_list,
 						   GAppInfo   *app);
 gboolean    fr_window_update_files                (FrWindow   *window,
-						   GList      *file_list);			   
+						   GList      *file_list);
 void        fr_window_update_columns_visibility   (FrWindow   *window);
 void        fr_window_update_history_list         (FrWindow   *window);
 void        fr_window_set_default_dir             (FrWindow   *window,
@@ -297,15 +301,15 @@ void       fr_window_set_batch__extract_here      (FrWindow      *window,
 void       fr_window_set_batch__add               (FrWindow      *window,
 						   const char    *archive,
 						   GList         *file_list);
+void       fr_window_destroy_with_error_dialog    (FrWindow      *window);
 
 /**/
 
-void       fr_window_convert_data_free       (FrWindow         *window);
 gboolean   fr_window_file_list_drag_data_get (FrWindow         *window,
 					      GdkDragContext   *context,
 					      GtkSelectionData *selection_data,
 					      GList            *path_list);
 
-void       fr_window_update_dialog_closed    (FrWindow *window); 
+void       fr_window_update_dialog_closed    (FrWindow *window);
 
 #endif /* FR_WINDOW_H */
