@@ -70,16 +70,17 @@ char *      _gtk_entry_get_filename_text    (GtkEntry   *entry);
 void        _gtk_label_set_filename_text    (GtkLabel   *label,
 					     const char *text);
 char *      _gtk_label_get_filename_text    (GtkLabel   *label);
-GdkPixbuf * create_pixbuf                   (GtkIconTheme *icon_theme,
-					     const char   *icon_name,
-					     int           icon_size);
 GdkPixbuf * get_icon_pixbuf                 (GtkIconTheme *icon_theme,
 		 			     GThemedIcon  *icon,
-		 			     int           size); 
+		 			     int           size);
 GdkPixbuf * get_mime_type_pixbuf            (const char   *mime_type,
 		                             int           icon_size,
 		                             GtkIconTheme *icon_theme);
 int         get_folder_pixbuf_size_for_list (GtkWidget    *widget);
+gboolean    show_uri                        (GdkScreen   *screen,
+					     const char  *uri,
+				             guint32      timestamp,
+				             GError     **error);
 void        show_help_dialog                (GtkWindow    *parent,
 					     const char   *section);
 
